
/**
 * 名前が接頭辞で始まるチェックボックスにチェックがあるかを判定する関数
 * 
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    チェックありならtrue
 */
function isChecked(arg_form, txt_prefix)
{
    //[ フォームの各項目について繰り返し ]
    for (var i_cnt=0; i_cnt < arg_form.elements.length; i_cnt++)
    {
        // ある接頭辞をもつcheckboxのみ設定する。
        if (arg_form.elements[i_cnt].type =='checkbox' && 
            arg_form.elements[i_cnt].name.indexOf(txt_prefix) == 0 && 
            arg_form.elements[i_cnt].checked == true) {
            return true;
        }
    }
    return false;
}

/**
 * ブログ一覧の削除確認
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    OK:true
 */
function confirmDeleteBlogList(arg_form, txt_prefix)
{
    //[ ブログが選択済 ]
    if(isChecked(arg_form, txt_prefix)) {
        if(window.confirm('選択しているブログを削除します。よろしいですか？')) {
            return true;
        }
    }
    else{
        alert('ブログが選択されていません。削除するブログを選択してください。');
    }
    return false;
}

/**
 * ブログ一覧の選択チェック
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    選択あり：true
 */
function checkBlogListSelected(arg_form, txt_prefix)
{
    //[ ブログ選択なし ]
    if(! isChecked(arg_form, txt_prefix)) {
        alert('ブログが選択されていません。ブログを選択してください。');
        return false;
    }
    return true;
}

/**
 * ブログ変更の削除確認
 *
 * @return bool    OK：true
 */
function confirmDeleteBlog()
{
    if(window.confirm('ブログを削除します。よろしいですか？')) {
        return true;
    }

    return false;
}

/**
 * ブログ検索の条件チェック
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:チェックボックスの接頭辞
 * @return bool    チェック結果が正常：true
 */
function checkBlogSearch(arg_form, txt_prefix)
{
    //[ チェックなし、キーワードあり ]
    if((! isChecked(arg_form, txt_prefix)) && arg_form.s_keyword.value != '') {
        alert('検索対象項目が選択されていません。チェックボックスから選択してください。');
        return false;
    }
    //[ チェックあり、キーワードなし ]
    if((isChecked(arg_form, txt_prefix)) && arg_form.s_keyword.value == '') {
        alert('キーワードを入力してください。');
        return false;
    }
    return true;
}

/**
 * ブログ検索の条件クリア
 * 
 * @param  object  arg_form  [IN]:対象フォーム
 * @return bool    true
 */
function resetBlogSearch(arg_form)
{
    arg_form.s_keyword.value = '';
    arg_form.s_name.checked = false;
    arg_form.s_desc.checked = false;
    arg_form.s_group.checked = false;
    arg_form.s_user.checked = false;

    return true;
}

/**
 * グループ一覧の削除確認
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    OK:true
 */
function confirmDeleteGroupList(arg_form, txt_prefix)
{
    //[ グループが選択済 ]
    if(isChecked(arg_form, txt_prefix)) {
        if(window.confirm('選択しているグループを削除します。よろしいですか？')) {
            return true;
        }
    }
    else{
        alert('グループが選択されていません。削除するグループを選択してください。');
    }
    return false;
}

/**
 * グループ一覧の選択チェック
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    選択あり：true
 */
function checkGroupListSelected(arg_form, txt_prefix)
{
    //[ グループ選択なし ]
    if(! isChecked(arg_form, txt_prefix)) {
        alert('グループが選択されていません。グループを選択してください。');
        return false;
    }
    return true;
}

/**
 * グループ変更の削除確認
 *
 * @return bool    OK：true
 */
function confirmDeleteGroup()
{
    if(window.confirm('グループを削除します。よろしいですか？')) {
        return true;
    }

    return false;
}

/**
 * ユーザー一覧の削除確認
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    OK:true
 */
function confirmDeleteUserList(arg_form, txt_prefix)
{
    //[ ユーザーが選択済 ]
    if(isChecked(arg_form, txt_prefix)) {
        if(window.confirm('選択しているユーザーを削除します。よろしいですか？')) {
            return true;
        }
    }
    else{
        alert('ユーザーが選択されていません。削除するユーザーを選択してください。');
    }
    return false;
}

/**
 * ユーザー一覧の選択チェック
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    選択あり：true
 */
function checkUserListSelected(arg_form, txt_prefix)
{
    //[ ユーザー選択なし ]
    if(! isChecked(arg_form, txt_prefix)) {
        alert('ユーザーが選択されていません。ユーザーを選択してください。');
        return false;
    }
    return true;
}

/**
 * ユーザー変更の削除確認
 *
 * @return bool    OK：true
 */
function confirmDeleteUser()
{
    if(window.confirm('ユーザーを削除します。よろしいですか？')) {
        return true;
    }

    return false;
}

/**
 * ユーザー検索の条件クリア
 * 
 * @param  object  arg_form  [IN]:対象フォーム
 * @return bool    true
 */
function resetUserSearch(arg_form)
{
    arg_form.s_keyword.value = '';

    return true;
}

/**
 * テンプレート一覧の削除確認
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    OK:true
 */
function confirmDeleteTemplateList(arg_form, txt_prefix)
{
    //[ テンプレートが選択済 ]
    if(isChecked(arg_form, txt_prefix)) {
        if(window.confirm('選択しているテンプレートを削除します。よろしいですか？')) {
            return true;
        }
    }
    else{
        alert('テンプレートが選択されていません。削除するテンプレートを選択してください。');
    }
    return false;
}

/**
 * テンプレート覧の選択チェック
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    選択あり：true
 */
function checkTemplateListSelected(arg_form, txt_prefix)
{
    //[ ユーザー選択なし ]
    if(! isChecked(arg_form, txt_prefix)) {
        alert('テンプレートが選択されていません。テンプレートを選択してください。');
        return false;
    }
    return true;
}

/**
 * テンプレート変更の削除確認
 *
 * @return bool    OK：true
 */
function confirmDeleteTemplate()
{
    if(window.confirm('テンプレートを削除します。よろしいですか？')) {
        return true;
    }

    return false;
}

/**
 * ディレクトリ一覧の削除確認
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  id          [IN]:ディレクトリID
 * @param  bool    conf        [IN]:確認フラグ
 * @return bool    OK:true
 */
function confirmDeleteDirectoryList(arg_form, id, conf)
{
    //[ ディレクトリが選択済 ]
    if(id){
        //[ confirm表示する？]
        if(conf == 1) {
            if(window.confirm('選択しているディレクトリを削除します。よろしいですか？')) {
                return true;
            }
        }
        //[ confirm表示しない？]
        else{
            return true;
        }
    }
    //[ ディレクトリが未選択 ]
    else{
        return true;
    }
    return false;
}

/**
 * ディレクトリ変更の削除確認
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  bool    conf        [IN]:確認フラグ
 * @return bool    OK:true
 */
function confirmDeleteDirectory(arg_form, conf)
{
    //[ confirm表示する？]
    if(conf == 1) {
        if(window.confirm('ディレクトリを削除します。よろしいですか？')) {
    　      return true;
        }
    }
    //[ confirm表示しない？]
    else{
        return true;
    }
    return false;
}

/**
 * アクセスログの削除確認
 * @return bool    OK:true
 */
function confirmDeleteAccessLog()
{
    if(window.confirm('アクセスログ情報とランキング情報を削除します。よろしいですか？')) {
        return true;
    }
    return false;
}

/**
 * ブログ別使用ディスク検索の条件クリア
 * 
 * @param  object  arg_form  [IN]:対象フォーム
 * @return bool    true
 */
function resetDiskBlogSearch(arg_form)
{
    arg_form.s_keyword.value = '';
    arg_form.s_name.checked = false;
    arg_form.s_desc.checked = false;

    return true;
}

/**
 * ライセンス一覧の削除確認
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 * @return bool    OK:true
 */
function confirmDeleteLicenseList(arg_form, txt_prefix)
{
    //[ ライセンスが選択済 ]
    if(isChecked(arg_form, txt_prefix)) {
        if(window.confirm('選択しているライセンスを削除します。よろしいですか？')) {
            return true;
        }
    }
    else{
        alert('ライセンスが選択されていません。削除するライセンスを選択してください。');
    }
    return false;
}

/**
 * テンプレート部品の削除確認
 * @param  object  arg_form    [IN]:フォームオブジェクト
 * @param  string  txt_prefix  [IN]:接頭辞
 *
 */
function confirmDeleteTemplateItem(arg_form, txt_prefix)
{
    //[ 部品が選択済 ]
    if(isChecked(arg_form, txt_prefix)) {
        if(window.confirm('選択しているテンプレート部品を削除します。よろしいですか？')) {
            return true;
        }
    }
    else{
        alert('テンプレート部品が選択されていません。削除するテンプレート部品を選択してください。');    }

    return false;
}
