/**
 * desknet's Blog タグ -> HTML タグ
 * 
 * @param  string  text [IN]:文字列
 */
function dnblogtag_to_htmltag(text, img_path, is_escaped)
{
    function dnblogtag_to_htmltag_emoji_callback(matchedText, emoji)
    {
       var gif = getEmojiStrOrGif(emoji, true);

       if(gif) {
           return '<img src="'+img_path+'emoji/'+gif+'" border="0">';
       }

       return matchedText;
    }

    text = text.replace(/\[\[([^\]\]]+)\]\]/ig, dnblogtag_to_htmltag_emoji_callback);
    text = text.replace(/\[\{(image)\|(\d+)\|(\d*)\|(\d*)\|(\w*)\|([^}]*)\}\]/ig, dnblogtag_to_htmltag_callback);
    text = text.replace(/\[\{(file)\|(\d+)\|(\d*)\|(\d*)\|(\w*)\|([^}]*)\}\]/ig, dnblogtag_to_htmltag_callback);

    return text;
}

/**
 * HTMLエンコード文字列→HTMLデコード文字列
 * 
 * @param  string  html        [IN]:HTMLエンコード文字列
 */
function decodeHtml(str) 
{
    return str.replace(/&nbsp;/ig, " ")
              .replace(/&quot;/ig, "\"")
              .replace(/&gt;/ig, ">")
              .replace(/&lt;/ig, "<")
              .replace(/&amp;/ig, "&");
}

/**
 * desknet's Blog タグ -> HTML タグ用の変換コールバック
 * 
 * @param  string  matchedText [IN]:文字列
 * @param  string  ...         [IN]:正規表現の()の中身を前から順に
 */
function dnblogtag_to_htmltag_callback(matchedText, tag, id, width, height, align, alt)
{
    var text = '';
    var img_flg = '';

    if (tag.toLowerCase() == 'file')
    {
        img_flg = '&image=1';
    }

    var decodealt = decodeHtml(alt);

    var img_src = 'index.php?module=Default&action=GetFile'+'&i_file_name='+encodeURIComponent(decodealt)+'&blog_sys_id='+blog_sys_id+img_flg+'&i_file_id='+id;

    text = '<img src="'+img_src+'"';

    if (alt.length > 0)
    {
        text = text + ' alt="'+alt+'"';
    }
    if (align.length > 0)
    {
        text = text + ' align="'+align+'"';
    }
    if (height.length > 0)
    {
        text = text + ' height="'+height+'"';
    }
    if (width.length > 0)
    {
        text = text + ' width="'+width+'"';
    }

    text = text + ' border="0">';
    return text;
}

/**
 * HTML タグ -> desknet's Blogタグ
 * 
 * @param  string  text [IN]:文字列
 */
function htmltag_to_dnblogtag(text)
{
    var sTname    = 'image';
    var sFileId   = '';
    var sAlign    = '';
    var sWidth    = '';
    var sHeight   = '';
    var sAlt      = '';
    var sRet      = '';

    sRet = text.replace(/<img [^<]*?src="images\/emoji\/(\w+\.gif)".*?>/igm,
            function() {
                return '[[' + getEmojiStrOrGif(arguments[1], false) + ']]';
            });

    sRet = sRet.replace(/<img [^<]*?src="index.php[^ ]*?i_file_id=\d+.*?>/igm,
            function(sAll) {
                sTname    = 'image';
                sFileId   = '';
                sAlign    = '';
                sWidth    = '';
                sHeight   = '';
                sAlt      = '';

                if (sAll.match(/ src="index\.php[^ ]*?[&|&amp;]image=1/i)) {
                    sTname = 'file';
                }

                if (sAll.match(/ src="index\.php[^ ]*?[&|&amp;]i_file_id=(\d+).*?>/i)) {
                    sFileId = RegExp.$1;
                }

                if (sAll.match(/ width="(\d+)" /i)) {
                    sWidth = RegExp.$1;
                }

                if (sAll.match(/ height="(\d+)" /i)) {
                    sHeight = RegExp.$1;
                }

                if (sAll.match(/ align="(\w+)" /i)) {
                    sAlign = RegExp.$1;
                }

                if (sAll.match(/ alt="([^"]+)" /i)) {
                    sAlt = RegExp.$1;

                }

                return '[{' +  sTname + '|' + sFileId + '|' + sWidth + '|'
                       + sHeight + '|' + sAlign + '|' + sAlt + '}]';
            });

    return sRet;
}
